Module cli

Module cli 

CLI argument definitions and validation.

Structs

CliArgs
CLI arguments for pdf-vdiff.

Functions

opt_path_stem_or
Extract the file stem from an optional path or return fallback if absent or invalid UTF-8.
path_file_name_or
Extract the file name as string or return fallback if not present or invalid UTF-8.
path_stem_or
Extract the file stem as string or return fallback if not present or invalid UTF-8.
render_completions
Render shell completion script for pdf-vdiff to the given writer.
render_man_page
Render the roff man page (Section 1) for pdf-vdiff to the given writer.