CLI argument definitions and validation.
Structs
- CliArgs
- CLI arguments for
pdf-vdiff.
Functions
- opt_
path_ stem_ or - Extract the file stem from an optional path or return fallback if absent or invalid UTF-8.
- path_
file_ name_ or - Extract the file name as string or return fallback if not present or invalid UTF-8.
- path_
stem_ or - Extract the file stem as string or return fallback if not present or invalid UTF-8.
- render_
completions - Render shell completion script for
pdf-vdiffto the given writer. - render_
man_ page - Render the roff man page (Section 1) for
pdf-vdiffto the given writer.